@@ -4,7 +4,7 @@
  * Home page: http://plasma-gate.weizmann.ac.il/Grace/
  * 
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
- * Copyright (c) 1996-2000 Grace Development Team
+ * Copyright (c) 1996-2002 Grace Development Team
  * 
  * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
  * 
@@ -869,8 +869,8 @@ static int uniread(FILE *fp, int load_type, char *label)
                 readerror = 0;
                 breakon = TRUE;
             }
-	    if (linebuf[0] == '@') {
-                scanner(linebuf + 1);
+	    if (*s == '@') {
+                scanner(s + 1);
 	        continue;
             }
 	} else {
@@ -1169,8 +1169,17 @@ int save_project(char *fn)
 {
     FILE *cp;
     int gno, setno;
+    char *old_fn;
+    int noask_save = noask;
+    
+    old_fn = get_docname();
+    if (compare_strings(old_fn, fn)) {
+        /* If saving under the same name, don't warn about overwriting */
+        noask = TRUE;
+    }
     
     if ((cp = grace_openw(fn)) == NULL) {
+        noask = noask_save;
 	return RETURN_FAILURE;
     }
     
@@ -1187,6 +1196,7 @@ int save_project(char *fn)
     set_docname(fn);
     clear_dirtystate();
     
+    noask = noask_save;
     return RETURN_SUCCESS;
 }
 
